package cmd

import (
	"github.com/carapace-sh/carapace"
	"github.com/spf13/cobra"
)

var self_updateCmd = &cobra.Command{
	Use:   "update",
	Short: "Download and install updates to rustup",
	Run:   func(cmd *cobra.Command, args []string) {},
}

func init() {
	carapace.Gen(self_updateCmd).Standalone()

	self_updateCmd.Flags().BoolP("help", "h", false, "Print help")
	selfCmd.AddCommand(self_updateCmd)
}
